pub struct Keystore(/* private fields */);Expand description
A persistent keystore backed by a JSON file with exclusive locking.
Implementations
Sourceimpl Keystore
impl Keystore
Sourcepub fn create(
path: &Path,
testing_prng_seed: Option<u64>,
) -> Result<Self, Error>
pub fn create( path: &Path, testing_prng_seed: Option<u64>, ) -> Result<Self, Error>
Creates a new keystore at path. If testing_prng_seed is provided,
uses deterministic key generation.
Sourcepub async fn generate_key(&mut self) -> Result<AccountPublicKey, Error>
pub async fn generate_key(&mut self) -> Result<AccountPublicKey, Error>
Generates a new key pair, persists the keystore, and returns the public key.
Sourcepub async fn generate_keys(
&mut self,
count: usize,
) -> Result<Vec<AccountPublicKey>, Error>
pub async fn generate_keys( &mut self, count: usize, ) -> Result<Vec<AccountPublicKey>, Error>
Generates count new key pairs, persists the keystore, and returns the public keys.
Sourcepub fn into_signer(self) -> InMemorySigner
pub fn into_signer(self) -> InMemorySigner
Consumes the keystore and returns the inner signer.